pub struct LuaThreadClose(pub LuaStatus);Expand description
Internal control-flow payload for Lua 5.5 coroutine.close() self-close.
It is caught at the coroutine resume boundary; panic hooks should suppress it
like LuaExit because it is not a Rust runtime panic.
Tuple Fields
0: LuaStatusTrait Implementations
Sourceimpl Clone for LuaThreadClose
impl Clone for LuaThreadClose
Sourcefn clone(&self) -> LuaThreadClose
fn clone(&self) -> LuaThreadClose
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LuaThreadClose
Sourceimpl Debug for LuaThreadClose
impl Debug for LuaThreadClose
impl Eq for LuaThreadClose
Sourceimpl PartialEq for LuaThreadClose
impl PartialEq for LuaThreadClose
Sourcefn eq(&self, other: &LuaThreadClose) -> bool
fn eq(&self, other: &LuaThreadClose) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LuaThreadClose