Module upval

Module upval 

UpVal — closure upvalues. PORT_STRATEGY 3.8.

Structs

UpVal
A closure upvalue. Open upvalues point at a slot on a thread’s stack (referred to by index, since the stack reallocates). Closed upvalues own the value.

Enums

UpValState
Discriminator state for an upvalue: either still pointing at a thread’s stack slot, or owning the value after close.