LuaError and its canonical constructors. PORT_STRATEGY 3.7, PORTING.md 6.
Structs
- LuaExit
- Internal control-flow payload used by the standalone CLI to implement
os.exitwithout making Lua protected calls catch it as an ordinary error.
Enums
- LuaError
- The Lua error type. Carries a
LuaValuepayload because Lua errors can be any value (typically a string).